/*----------------------

   GATE - Geant4 Application for Tomographic Emission 
   OpenGATE Collaboration 
     
   Giovanni Santin <giovanni.santin@cern.ch> 
   Daniel Strul <daniel.strul@iphe.unil.ch> 
     
   Copyright (C) 2002 UNIL/IPHE, CH-1015 Lausanne 

This software is distributed under the terms 
of the GNU Lesser General  Public Licence (LGPL) 
See GATE/LICENSE.txt for further details 
----------------------*/

/*!
  \file GateTrajectoryNavigator.hh
  
  $Log: GateTrajectoryNavigator.hh,v $
  Revision 1.1.1.1  2005/02/03 13:09:53  jdbeen
  gate cluster code for G4.6.2

  Revision 1.5  2002/11/25 15:16:28  gsantin
  adaptations for SPECT, handling of photon trajectories not only in pairs

  Revision 1.4  2002/08/11 15:33:24  dstrul
  Cosmetic cleanup: standardized file comments for cleaner doxygen output


  \brief Class GateTrajectoryNavigator
  \brief By Giovanni.Santin@cern.ch
  \brief $Id: GateTrajectoryNavigator.hh,v 1.1.1.1 2005/02/03 13:09:53 jdbeen Exp $
*/
#ifndef GateTrajectoryNavigator_H
#define GateTrajectoryNavigator_H

#include "globals.hh"
#include "G4ThreeVector.hh"
#include <vector>

class G4TrajectoryContainer;
class G4Trajectory;


class GateTrajectoryNavigator
{
public:

  GateTrajectoryNavigator();

  virtual ~GateTrajectoryNavigator();
  

  G4int         FindSourceIndex();

  G4ThreeVector FindSourcePosition();

  G4int         FindPositronTrackID();

  std::vector<G4int> FindAnnihilationGammasTrackID();

  G4int         FindPhotonID(G4int trackID);

  G4int         FindPrimaryID(G4int trackID);

  void          Initialize();

  void                          SetTrajectoryContainer(G4TrajectoryContainer* trajectoryContainer);  

  inline G4TrajectoryContainer* GetTrajectoryContainer()   { return m_trajectoryContainer; };  

  inline std::vector<G4int>          GetPhotonIDVec()           { return m_photonIDVec; };

  inline G4int                  GetPositronTrackID()       { return m_positronTrackID; };

  void                          SetIonID();

  void                          SetVerboseLevel(G4int val) { m_verboseLevel = val; };

//dk
  G4int                 FindPrimType(G4int trackID, G4int gam1_ID, G4int gam2_ID);
  inline G4double       FindPrimEnergy() const { return m_PrimEnergy;};
private:
  G4double m_PrimEnergy;
//dk_end
   
protected:

private:
  G4TrajectoryContainer* m_trajectoryContainer;
  
  std::vector<G4int>          m_photonIDVec;
  G4int                  m_positronTrackID;
  G4Trajectory*          m_positronTrj;
  G4int                  m_ionID;

  G4int                  m_verboseLevel;
};


#endif
